CpuFrameSource class

Inheritance

Constructors

CpuFrameSource({required Uint8List bytes, required MiniAVPixelFormat pixelFormat, required int width, required int height, List<int>? strideBytes, int timestampUs = 0})
const

Properties

bytes Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
height int
Frame height in pixels.
final
kind FrameSourceKind
What kind this is, for backend capability checks.
no setteroverride
pixelFormat MiniAVPixelFormat
Pixel format. Backends may need to perform color-space conversion.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strideBytes List<int>?
final
timestampUs int
Presentation timestamp in microseconds. May be 0 if unknown.
final
width int
Frame width in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited